PyXMake Developer Guide: PyXMake.VTL.ifort Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.ifort Namespace Reference

## Functions
def | main (BuildID, files=VTL.GetSourceCode(0), command=VTL.GetBuildCommand(2), libs=VTL.GetLinkDependency(0, 2, __arch), source=os.path.join(__mcd_core_path,"src"), include=[os.path.join(__mcd_core_path,"include", Utility.GetPlatform(), __arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)], dependency=os.path.join(__mcd_core_path,"lib", Utility.GetPlatform(), __arch), make=[os.path.join(__mcd_core_path,"include", Utility.GetPlatform(), __arch), os, path, join, __mcd_core_path, lib, Utility, GetPlatform, __arch, architecture=__arch, scratch=VTL.Scratch, verbosity=2, incremental=False, kwargs)

## Variables
| parser = argparse.ArgumentParser(description="Build a static Fortran library remotely on the current machine")
| args
| make_opt = args.make[0]
string | BuildID = "bbeam"
| box_source = os.path.join(__mcd_core_path,"external","boxbeam")
list | box_make
| files
| source = os.path.join(__mcd_core_path,"external","toms")
| include
| make
| libs
| beos_source = os.path.join(__mcd_core_path,"external",BuildID)
list | beos_make = [None, os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch)]
| command
| incremental
list | dam_make
list | disp_make
list | BuildIDs = [os.path.splitext(x)[0].lower() for x in VTL.GetSourceCode(6)]
list | srcfile = [x for x in VTL.GetSourceCode(6) if x.startswith(BuildID)]
string | style = False
bool | combine = True
dictionary | pchip_replace
| replace
| verbose

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile a static Fortran library using Intel Fortran.
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          - Added 3rd party dependencies to build process. Requires
            PyCODAC in PYTHONPATH.

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

def PyXMake.VTL.ifort.main | ( |  | BuildID,
|  |  | files = `VTL.GetSourceCode(0)`,
|  |  | command = `VTL.GetBuildCommand(2)`,
|  |  | libs = `VTL.GetLinkDependency(0, 2, __arch)`,
|  |  | source = `os.path.join(__mcd_core_path,"src")`,
|  |  | include = `[os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)]`,
|  |  | dependency = `os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch)`,
|  |  | make = `[os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch)`,
|  |  | os,
|  |  | path,
|  |  | join,
|  |  | __mcd_core_path,
|  |  | lib,
|  |  | Utility,
|  |  | GetPlatform,
|  |  | __arch,
|  |  | architecture = `__arch`,
|  |  | scratch = `VTL.Scratch`,
|  |  | verbosity = `2`,
|  |  | incremental = `False`,
|  |  | kwargs
| ) |  |

    Main function to execute the script.

Definition at line 70 of file ifort.py.

## Variable Documentation

## ◆ box_make

PyXMake.VTL.ifort.box_make

Initial value:
1 = [os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch,"boxbeam"),
2 os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch)]

Definition at line 125 of file ifort.py.

## ◆ dam_make

PyXMake.VTL.ifort.dam_make

Initial value:
1 = [os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch,BuildID),
2 os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch)]

Definition at line 138 of file ifort.py.

## ◆ disp_make

PyXMake.VTL.ifort.disp_make

Initial value:
1 = [os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch,BuildID),
2 os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch)]

Definition at line 149 of file ifort.py.

## ◆ make

list PyXMake.VTL.ifort.make

Initial value:
1 = [os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch, "toms"),
2 os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch)]

Definition at line 127 of file ifort.py.

## ◆ pchip_replace

dictionary PyXMake.VTL.ifort.pchip_replace

Initial value:
1 = {'FUNCTION RAND ( R )':'FUNCTION RAND ( R ) BIND(C, NAME="pchip_rand")',
2 'subroutine timestamp ( )':'subroutine timestamp ( ) BIND(C, NAME="pchip_timestamp")'}

Definition at line 175 of file ifort.py.